@@ -254,7 +254,15 @@ class CameraActivitySettings(TypedDict):
 
 CameraType = Literal["camera", "doorbell"]
 
-CameraFrameWorker = Literal["pillow", "sharp", "wasm"]
+CameraFrameWorkerDecoder = Literal["pillow", "wasm"]
+
+CameraFrameWorkerResolution = Literal[640, 480, 320]
+
+
+class CameraFrameWorkerSettings(TypedDict):
+    decoder: CameraFrameWorkerDecoder
+    fps: int
+    resolution: CameraFrameWorkerResolution
 
 
 class Camera(TypedDict):
@@ -279,7 +287,7 @@ class Camera(TypedDict):
     hasIntercom: bool
     hasPtz: bool
     sources: list[CameraInput]
-    frameWorker: Literal["pillow", "sharp", "wasm"]
+    frameWorkerSettings: CameraFrameWorkerSettings
 
 
 CameraPublicProperties = Literal[
@@ -304,7 +312,7 @@ CameraPublicProperties = Literal[
     "hasIntercom",
     "hasPtz",
     "sources",
-    "frameWorker",
+    "frameWorkerSettings",
 ]
 
 PropertyValue = Union[
@@ -674,8 +682,11 @@ class CameraSource(Protocol):
     async def get_stream_info(self) -> Optional[StreamInfo]: ...
 
 
+ImageOutputFormat = Literal["rgb", "rgba", "gray"]
+
+
 class ImageFormat(TypedDict):
-    to: Literal["rgba", "gray"]
+    to: ImageOutputFormat
 
 
 class ImageCrop(TypedDict):
@@ -696,15 +707,21 @@ class ImageOptions(TypedDict):
     resize: NotRequired[ImageResize]
 
 
+ImageInputFormat = Literal["yuv", "rgb", "rgba"]
+
+
 class IceServer(TypedDict):
     urls: list[str]
     username: NotRequired[str]
     credential: NotRequired[str]
 
 
+DecoderFormat = Literal["yuv", "rgb"]
+
+
 class FrameMetadata(TypedDict):
-    format: str
-    frameSize: int
+    format: DecoderFormat
+    frameSize: float
     width: int
     height: int
     origWidth: int
@@ -714,7 +731,8 @@ class FrameMetadata(TypedDict):
 class ImageInformation(TypedDict):
     width: int
     height: int
-    channels: int
+    channels: Literal[1, 3, 4]
+    format: ImageOutputFormat
 
 
 class FrameBuffer(TypedDict):
@@ -774,6 +792,7 @@ class CameraDevice(Protocol):
     sources: list[CameraSource]
     activity_zones: list[DetectionZone]
     activity_settings: CameraActivitySettings
+    frameworker_settings: CameraFrameWorkerSettings
     is_cloud: bool
     has_light: bool
     has_siren: bool
